==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/ar.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} متوفر.  أحصل على معلومات كيفية التحديث.",
    "Channel updated" : "حُدثت القناة",
    "Update notifications" : "إشعارات التحديث",
    "The update server could not be reached since %d days to check for new updates." : "تعذر الوصول إلى خادم التحديث منذ %d أيام للتحقق من وجود تحديثات جديدة.",
    "Please check the Nextcloud and server log files for errors." : "يرجى التحقق من Nextcloud وملفات تسجيل الخادم بحثًا عن الأخطاء.",
    "Update to %1$s is available." : "التحديث إلى %1$s متوفر.",
    "Update for %1$s to version %2$s is available." : "التحديث من النسخة %1$s إلى %2$s متوفر.",
    "Update for {app} to version %s is available." : "التحديث ل {app} نسخة رقم %s متوفر.",
    "Update notification" : "إشعار التحديث",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "يعرض إشعارات التحديث لـ Nextcloud ويوفر SSO للمُحدِّث.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "لم يعد الإصدار الذي تقوم بتشغيله قيد الصيانة. يرجى التأكد من التحديث إلى إصدار مدعوم في أقرب وقت ممكن.",
    "Apps missing updates" : "التطبيقات تفقد تحديثات",
    "View in store" : "العرض على المتجر",
    "Apps with available updates" : "يتوفر تحديثات للتطبيقات",
    "Open updater" : "فتح المحدِّث",
    "Download now" : "حمل الآن",
    "What's new?" : "مالجديد؟",
    "The update check is not yet finished. Please refresh the page." : "التحقق من التحديث لم ينته بعد. يرجى تحديث الصفحة.",
    "Your version is up to date." : "النسخة لديك هي الأحدث.",
    "A non-default update server is in use to be checked for updates:" : "يتم استخدام خادم تحديث غير افتراضي للتحقق من وجود تحديثات:",
    "Update channel:" : "قناة التحديث:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "يمكنك دائمًا التحديث إلى إصدار أحدث. لكن لا يمكنك الرجوع إلى إصدار أكثر استقرارًا.",
    "Notify members of the following groups about available updates:" : "إشعار أعضاء المجموعات التالية بتوفر التحديثات:",
    "Only notification for app updates are available." : "يتوفر إشعار فقط عن تحديثات التطبيق.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "قناة التحديث المحددة تجعل الإشعارات المخصصة للخادم قديمة.",
    "The selected update channel does not support updates of the server." : "قناة التحديث المحددة لا تدعم تحديثات الخادم.",
    "A new version is available: <strong>{newVersionString}</strong>" : "توجد نسخة جديدة: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "فحص في {lastCheckedDate}",
    "Checking apps for compatible updates" : "التحقق من التطبيقات للحصول على تحديثات متوافقة",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "الرجاء التأكد أن ملف الconfig.php الخاص بك لا يعين قيمة <samp>appstoreenabled</samp> إلى false.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "تعذر الاتصال بمتجر التطبيقات أو أن متجر التطبيقات لم يُرجع أي تحديثات على الإطلاق. ابحث يدويًا عن التحديثات أو تأكد من وصول الخادم إلى الإنترنت ويمكنه الاتصال بمتجر التطبيقات.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>جميع</strong> التطبيقات لديها تحديث لهذا الإصدار",
    "View changelog" : "اعرض سجل التغييرات",
    "Enterprise" : "المؤسسة",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "لاستخدام المؤسسات. يوفر دائمًا أحدث مستوى من التصحيح ، ولكنه لن يتم تحديثه إلى الإصدار الرئيسي التالي على الفور. يحدث هذا التحديث بمجرد أن تقوم شركة Nextcloud GmbH بإجراء مزيد من الصلابة والاختبار لعمليات النشر واسعة النطاق والمهمة. هذه القناة متاحة فقط للعملاء وتوفر حزمة Nextcloud للمؤسسة.",
    "Stable" : "مستقر",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "أحدث نسخة مستقرة.  مناسبه للاستخدام المنتظم وسيتم تحديثه دائمًا إلى أحدث إصدار رئيسي.",
    "Beta" : "تجريبي",
    "A pre-release version only for testing new features, not for production environments." : "نسخة تجريبية فقط لاختبار الميزات الجديدة ، وليس لبيئات الإنتاجية.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> تطبيق لا يوجد لديه تحديث لهذه النسخة","<strong>%n</strong> تطبيق لا يوجد لديه تحديث لهذه النسخة","<strong>%n</strong> تطبيقان لا يوجد لديهم تحديث لهذه النسخة","<strong>%n</strong> تطبيقات لا توجد لديها تحديث لهذه النسخة","<strong>%n</strong> تطبيقات لا توجد لديها تحديث لهذه النسخة","<strong>%n</strong>تطبيقات لا توجد لديها تحديث لهذه النسخة"],
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "لاحظ أنه بعد نزول إصدار جديد، قد يستغرق الأمر بعض الوقت قبل ظهوره هنا. نطرح إصدارات جديدة موزعة بمرور الوقت على مستخدمينا وأحيانًا نتخطى إصدارًا عند اكتشاف مشاكل."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-21.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/ar.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} متوفر.  أحصل على معلومات كيفية التحديث.",
    "Channel updated" : "حُدثت القناة",
    "Update notifications" : "إشعارات التحديث",
    "The update server could not be reached since %d days to check for new updates." : "تعذر الوصول إلى خادم التحديث منذ %d أيام للتحقق من وجود تحديثات جديدة.",
    "Please check the Nextcloud and server log files for errors." : "يرجى التحقق من Nextcloud وملفات تسجيل الخادم بحثًا عن الأخطاء.",
    "Update to %1$s is available." : "التحديث إلى %1$s متوفر.",
    "Update for %1$s to version %2$s is available." : "التحديث من النسخة %1$s إلى %2$s متوفر.",
    "Update for {app} to version %s is available." : "التحديث ل {app} نسخة رقم %s متوفر.",
    "Update notification" : "إشعار التحديث",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "يعرض إشعارات التحديث لـ Nextcloud ويوفر SSO للمُحدِّث.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "لم يعد الإصدار الذي تقوم بتشغيله قيد الصيانة. يرجى التأكد من التحديث إلى إصدار مدعوم في أقرب وقت ممكن.",
    "View in store" : "العرض على المتجر",
    "Open updater" : "فتح المحدِّث",
    "Download now" : "حمل الآن",
    "What's new?" : "مالجديد؟",
    "The update check is not yet finished. Please refresh the page." : "التحقق من التحديث لم ينته بعد. يرجى تحديث الصفحة.",
    "Your version is up to date." : "النسخة لديك هي الأحدث.",
    "A non-default update server is in use to be checked for updates:" : "يتم استخدام خادم تحديث غير افتراضي للتحقق من وجود تحديثات:",
    "Update channel:" : "قناة التحديث:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "يمكنك دائمًا التحديث إلى إصدار أحدث. لكن لا يمكنك الرجوع إلى إصدار أكثر استقرارًا.",
    "Notify members of the following groups about available updates:" : "إشعار أعضاء المجموعات التالية بتوفر التحديثات:",
    "The selected update channel makes dedicated notifications for the server obsolete." : "قناة التحديث المحددة تجعل الإشعارات المخصصة للخادم قديمة.",
    "The selected update channel does not support updates of the server." : "قناة التحديث المحددة لا تدعم تحديثات الخادم.",
    "A new version is available: <strong>{newVersionString}</strong>" : "توجد نسخة جديدة: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "فحص في {lastCheckedDate}",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "الرجاء التأكد أن ملف الconfig.php الخاص بك لا يعين قيمة <samp>appstoreenabled</samp> إلى false.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "تعذر الاتصال بمتجر التطبيقات أو أن متجر التطبيقات لم يُرجع أي تحديثات على الإطلاق. ابحث يدويًا عن التحديثات أو تأكد من وصول الخادم إلى الإنترنت ويمكنه الاتصال بمتجر التطبيقات.",
    "View changelog" : "اعرض سجل التغييرات",
    "Enterprise" : "المؤسسة",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "لاستخدام المؤسسات. يوفر دائمًا أحدث مستوى من التصحيح ، ولكنه لن يتم تحديثه إلى الإصدار الرئيسي التالي على الفور. يحدث هذا التحديث بمجرد أن تقوم شركة Nextcloud GmbH بإجراء مزيد من الصلابة والاختبار لعمليات النشر واسعة النطاق والمهمة. هذه القناة متاحة فقط للعملاء وتوفر حزمة Nextcloud للمؤسسة.",
    "Stable" : "مستقر",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "أحدث نسخة مستقرة.  مناسبه للاستخدام المنتظم وسيتم تحديثه دائمًا إلى أحدث إصدار رئيسي.",
    "Beta" : "تجريبي",
    "A pre-release version only for testing new features, not for production environments." : "نسخة تجريبية فقط لاختبار الميزات الجديدة ، وليس لبيئات الإنتاجية.",
    "Apps missing updates" : "التطبيقات تفقد تحديثات",
    "Apps with available updates" : "يتوفر تحديثات للتطبيقات",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "لاحظ أنه بعد نزول إصدار جديد، قد يستغرق الأمر بعض الوقت قبل ظهوره هنا. نطرح إصدارات جديدة موزعة بمرور الوقت على مستخدمينا وأحيانًا نتخطى إصدارًا عند اكتشاف مشاكل.",
    "Only notification for app updates are available." : "يتوفر إشعار فقط عن تحديثات التطبيق.",
    "Checking apps for compatible updates" : "التحقق من التطبيقات للحصول على تحديثات متوافقة",
    "<strong>All</strong> apps have an update for this version available" : "<strong>جميع</strong> التطبيقات لديها تحديث لهذا الإصدار",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> تطبيق لا يوجد لديه تحديث لهذه النسخة","<strong>%n</strong> تطبيق لا يوجد لديه تحديث لهذه النسخة","<strong>%n</strong> تطبيقان لا يوجد لديهم تحديث لهذه النسخة","<strong>%n</strong> تطبيقات لا توجد لديها تحديث لهذه النسخة","<strong>%n</strong> تطبيقات لا توجد لديها تحديث لهذه النسخة","<strong>%n</strong>تطبيقات لا توجد لديها تحديث لهذه النسخة"]
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
